==================
cubicweb.facets.js
==================
.. module:: cubicweb.facets.js

filter form, aka facets, javascript functions

 :organization: Logilab
 :copyright: 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr